@@ -3,11 +3,11 @@ package Test::MethodFixtures::Storage::File;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp;
 use Data::Dump qw( dump );
-use Digest::MD5 qw( md5_hex );;
+use Digest::MD5 qw( md5_hex );
 use Path::Tiny;
 
 use base 'Test::MethodFixtures::Storage';
